==> node-red-contrib-agilite-7.3.11.tgz: package/roles/roles.js <==
const Agilite = require('agilite')
const TypeDetect = require('agilite-utils/type-detect')
const EnumsTypeDetect = require('agilite-utils/enums-type-detect')
const { executeHandlebars } = require('agilite-utils')

module.exports = function (RED) {
  function Roles (config) {
    RED.nodes.createNode(this, config)

    const node = this
    const field = config.field || 'payload'
    const fieldType = config.fieldType || 'msg'

    node.status({
      fill: 'blue',
      text: 'ready',
      shape: 'ring'
    })

    this.on('input', async (msg) => {
      const serverConfig = RED.nodes.getNode(config.server)
      const apiServerUrl = serverConfig.server
      const failFlow = config.failFlow

      let agilite = null
      let roleName = config.roleName
      let conditionalLevels = config.conditionalLevels
      let apiKey = null
      let logProfileKey = null
      let data = msg.payload
      let errorMessage = null
      let result = null

      const submitResponse = (response) => {
        switch (fieldType) {
          case 'msg':
            RED.util.setMessageProperty(msg, field, response.data)
            break
          case 'flow':
            node.context().flow.set(field, response.data)
            break
          case 'global':
            node.context().global.set(field, response.data)
            break
        }

        node.status({
          fill: 'green',
          text: 'Success',
          shape: 'ring'
        })

        msg.agilite.success = true
        msg.agilite.errorMessage = ''

        node.send(msg)
      }

      const submitError = (error) => {
        errorMessage = null

        if (error.response && error.response.data.errorMessage) {
          errorMessage = error.response.data.errorMessage
        } else if (error.message) {
          errorMessage = error.message
        } else {
          errorMessage = error
        }

        node.status({
          fill: 'red',
          text: 'Error',
          shape: 'ring'
        })

        msg.agilite.success = false
        msg.agilite.errorMessage = errorMessage

        if (failFlow) {
          node.error(errorMessage, msg)
        } else {
          node.send(msg)
        }
      }

      try {
        // Check if there's an Agilit-e object in MSG
        if (TypeDetect(msg.agilite) !== EnumsTypeDetect.OBJECT) msg.agilite = {}

        // Set Log Profile Key and API Key
        logProfileKey = msg.agilite.logProfileKey || ''
        apiKey = msg.agilite.apiKey || serverConfig.credentials.apiKey

        // Validate Payload
        if (TypeDetect(data) !== EnumsTypeDetect.OBJECT) data = {}

        // Handlebars
        if (roleName) {
          roleName = executeHandlebars(roleName, msg)
          if ((TypeDetect(roleName) !== 'string') || (roleName === '[object Object]')) errorMessage = 'Invalid Role Name type provided. Expected a string'
        }
        if (conditionalLevels) {
          conditionalLevels = executeHandlebars(conditionalLevels, msg)
          if ((TypeDetect(conditionalLevels) !== 'string') || (conditionalLevels === '[object Object]')) errorMessage = 'Invalid Conditional Levels type provided. Expected a string'
        }

        //  Finalize array properties
        roleName = roleName.split(',')
        conditionalLevels = conditionalLevels.split(',')

        // We need a apiKey, key and data to proceed
        if (!apiKey) {
          errorMessage = 'No valid API Key Provided. Please authenticate with Agilit-e first'
        } else if (!apiServerUrl) {
          errorMessage = 'No Server URL Provided'
        } else {
          switch (config.actionType) {
            case '1': // Get Role
              if (!roleName) {
                errorMessage = 'No Role Name found'
              }

              break
          }
        }

        if (errorMessage) return submitError(errorMessage)

        agilite = new Agilite({ apiServerUrl, apiKey })

        node.status({
          fill: 'yellow',
          text: 'Running',
          shape: 'ring'
        })

        switch (config.actionType) {
          case '1': // Get Role
            result = await agilite.Roles.getRole(roleName, conditionalLevels, data, logProfileKey)
            break
          default:
            throw new Error('No valid Action Type specified')
        }

        submitResponse(result)
      } catch (e) {
        submitError(e)
      }
    })
  }

  RED.nodes.registerType('roles', Roles)
}

==> node-red-contrib-agilite-7.3.17.tgz: package/roles/roles.js <==
const Agilite = require('agilite')
const TypeDetect = require('agilite-utils/type-detect')
const EnumsTypeDetect = require('agilite-utils/enums-type-detect')
const { compileTemplate } = require('agilite-utils')

module.exports = function (RED) {
  function Roles (config) {
    RED.nodes.createNode(this, config)

    const node = this
    const field = config.field || 'payload'
    const fieldType = config.fieldType || 'msg'

    node.status({
      fill: 'blue',
      text: 'ready',
      shape: 'ring'
    })

    this.on('input', async (msg) => {
      const serverConfig = RED.nodes.getNode(config.server)
      const apiServerUrl = serverConfig.server
      const failFlow = config.failFlow

      let agilite = null
      let roleName = config.roleName
      let conditionalLevels = config.conditionalLevels
      let apiKey = null
      let logProfileKey = null
      let data = msg.payload
      let errorMessage = null
      let result = null

      const submitResponse = (response) => {
        switch (fieldType) {
          case 'msg':
            RED.util.setMessageProperty(msg, field, response.data)
            break
          case 'flow':
            node.context().flow.set(field, response.data)
            break
          case 'global':
            node.context().global.set(field, response.data)
            break
        }

        node.status({
          fill: 'green',
          text: 'Success',
          shape: 'ring'
        })

        msg.agilite.success = true
        msg.agilite.errorMessage = ''

        node.send(msg)
      }

      const submitError = (error) => {
        errorMessage = null

        if (error.response && error.response.data.errorMessage) {
          errorMessage = error.response.data.errorMessage
        } else if (error.message) {
          errorMessage = error.message
        } else {
          errorMessage = error
        }

        node.status({
          fill: 'red',
          text: 'Error',
          shape: 'ring'
        })

        msg.agilite.success = false
        msg.agilite.errorMessage = errorMessage

        if (failFlow) {
          node.error(errorMessage, msg)
        } else {
          node.send(msg)
        }
      }

      try {
        // Check if there's an Agilit-e object in MSG
        if (TypeDetect(msg.agilite) !== EnumsTypeDetect.OBJECT) msg.agilite = {}

        // Set Log Profile Key and API Key
        logProfileKey = msg.agilite.logProfileKey || ''
        apiKey = msg.agilite.apiKey || serverConfig.credentials.apiKey

        // Validate Payload
        if (TypeDetect(data) !== EnumsTypeDetect.OBJECT) data = {}

        // Handlebars
        if (roleName) {
          roleName = compileTemplate(roleName, msg)
          if ((TypeDetect(roleName) !== 'string') || (roleName === '[object Object]')) errorMessage = 'Invalid Role Name type provided. Expected a string'
        }
        if (conditionalLevels) {
          conditionalLevels = compileTemplate(conditionalLevels, msg)
          if ((TypeDetect(conditionalLevels) !== 'string') || (conditionalLevels === '[object Object]')) errorMessage = 'Invalid Conditional Levels type provided. Expected a string'
        }

        //  Finalize array properties
        roleName = roleName.split(',')
        conditionalLevels = conditionalLevels.split(',')

        // We need a apiKey, key and data to proceed
        if (!apiKey) {
          errorMessage = 'No valid API Key Provided. Please authenticate with Agilit-e first'
        } else if (!apiServerUrl) {
          errorMessage = 'No Server URL Provided'
        } else {
          switch (config.actionType) {
            case '1': // Get Role
              if (!roleName) {
                errorMessage = 'No Role Name found'
              }

              break
          }
        }

        if (errorMessage) return submitError(errorMessage)

        agilite = new Agilite({ apiServerUrl, apiKey })

        node.status({
          fill: 'yellow',
          text: 'Running',
          shape: 'ring'
        })

        switch (config.actionType) {
          case '1': // Get Role
            result = await agilite.Roles.getRole(roleName, conditionalLevels, data, logProfileKey)
            break
          default:
            throw new Error('No valid Action Type specified')
        }

        submitResponse(result)
      } catch (e) {
        submitError(e)
      }
    })
  }

  RED.nodes.registerType('roles', Roles)
}
